==> cakework-0.0.27.tar.gz: cakework-0.0.27/src/cakework/activity_server.py <==
# Copyright 2015 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""The Python implementation of the GRPC helloworld.Greeter server."""

from concurrent import futures
import logging
import grpc
from cakework import cakework_pb2
from cakework import cakework_pb2_grpc
import json
import importlib
# import os
import time
import threading
import requests

class Cakework(cakework_pb2_grpc.CakeworkServicer):
    def __init__(self, user_activity, local=False):
        self.user_activity = user_activity
        self.local = local
        if self.local:
            self.frontend_url = "http://localhost:8080"
        else:
            self.frontend_url = "https://cakework-frontend.fly.dev"

    def RunActivity(self, request, context):
        # update to in progress
        # response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": request.userId, "app": request.app, "requestId": request.requestId, "status": "IN_PROGRESS"})
        # TODO check the response
        parameters = json.loads(request.parameters)
        task = threading.Thread(target=self.background, args=[request.userId, request.app, request.requestId, parameters])
        task.daemon = True # Q: does returning kill the task?
        task.start()
        # what should we return? now, the client is no longer hitting the grpc server
        return cakework_pb2.Reply(result=json.dumps("worker started task")) # TODO this should return the request id

    # note: we need to get the request id in here as well
    def background(self, user_id, app, request_id, parameters):
        res = ""
        # print("starting background task with parameters: " + str(parameters))
        try:
            print("Starting request " + request_id)
            res = self.user_activity(**parameters)
            # TODO call the frontend api to update the status and result
            
            print("Finished request " + request_id)
            response = requests.patch(f"{self.frontend_url}/update-result", json={"userId": user_id, "app": app, "requestId": request_id, "result": json.dumps(res)})
            # TODO check the response
            response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "SUCCEEDED"})

        except Exception as e:
            print("got an error: ") # Q: do we want to expose this to customers? note: anything we put here will be printed to customer. 
            print(e)
            # print(e)
            response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "FAILED"})
            # TODO: handle case if updating the status in the db failed; then user may keep polling forever
            return cakework_pb2.Reply(result=None)

        # Q: who are we returning to here? instead of returning, we can just write this to the database. or emit a message and have the poller be in charge of writing to db
        return cakework_pb2.Reply(result=json.dumps(res))

def serve():
    port = '50051'
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=1)) # what should the default be?
    cakework_pb2_grpc.add_CakeworkServicer_to_server(Cakework(), server)
    server.add_insecure_port('[::]:' + port)
    server.start()
    print("Server started, listening on " + port)
    server.wait_for_termination()

if __name__ == '__main__':
    logging.basicConfig()
    serve()

class ActivityServer:
    def __init__(self, user_activity, local=False):
        self.user_activity = user_activity
        self.server = grpc.server(futures.ThreadPoolExecutor(max_workers=1)) # what should the default be?
        self.local = local

    def start(self):        
        port = '50051'
        cakework_pb2_grpc.add_CakeworkServicer_to_server(Cakework(self.user_activity, self.local), self.server)
        self.server.add_insecure_port('[::]:' + port)
        self.server.start()
        print("Server started, listening on " + port)
        self.server.wait_for_termination()

==> cakework-0.0.34.tar.gz: cakework-0.0.34/src/cakework/activity_server.py <==
# Copyright 2015 gRPC authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""The Python implementation of the GRPC helloworld.Greeter server."""

from concurrent import futures
import logging
import grpc
from cakework import cakework_pb2
from cakework import cakework_pb2_grpc
import json
import importlib
# import os
import time
import threading
import requests
import logging
import http.client
from cakework import auth

logging.basicConfig(level=logging.INFO)

class Cakework(cakework_pb2_grpc.CakeworkServicer):
    def __init__(self, user_activity, local=False):
        self.user_activity = user_activity
        self.local = local
        if self.local:
            self.frontend_url = "http://localhost:8080"
        else:
            self.frontend_url = "https://cakework-frontend.fly.dev"

    def RunActivity(self, request, context):
        # update to in progress
        scope = "update:status update:result"
        token = auth.get_token("l2OCkl1RIrWgYwaHeH394C0bXKJRIucI", "aYUDERY08rNhciuebW5rpShcU_KmcyY-RK-A55-ltkSmt-1mvAfAcJdVTsZDEBRh", scope) # TODO remove this from open source code
        headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + token}
        response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": request.userId, "app": request.app, "requestId": request.requestId, "status": "IN_PROGRESS"}, headers=headers)
        # TODO check the response
        parameters = json.loads(request.parameters)
        # parameters = json.loads(request.parameters) # instead of passing a dict (parameters), pass a variable number of parameters 
        task = threading.Thread(target=self.background, args=[request.userId, request.app, request.requestId, parameters, token])
        task.daemon = True # Q: does returning kill the task?
        task.start()
        # what should we return? now, the client is no longer hitting the grpc server
        return cakework_pb2.Reply(result=json.dumps("worker started task")) # TODO this should return the request id

    # note: we need to get the request id in here as well
    def background(self, user_id, app, request_id, parameters, token):
        res = ""
        # logging.info("starting background task with parameters: " + str(parameters))
        try:
            logging.info("Starting request " + request_id)
            res = self.user_activity(*parameters)
            # TODO call the frontend api to update the status and result
            
            logging.info("Finished request " + request_id)
            headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + token}
            response = requests.patch(f"{self.frontend_url}/update-result", json={"userId": user_id, "app": app, "requestId": request_id, "result": json.dumps(res)}, headers=headers)
            # TODO check the response
            response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "SUCCEEDED"}, headers=headers)

        except Exception as e:
            logging.exception("Error occurred while running task", exc_info=True)
            # logging.info(e)
            response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "FAILED"})
            # TODO: handle case if updating the status in the db failed; then user may keep polling forever
            return cakework_pb2.Reply(result=None)

        # Q: who are we returning to here? instead of returning, we can just write this to the database. or emit a message and have the poller be in charge of writing to db
        return cakework_pb2.Reply(result=json.dumps(res))

def serve():
    port = '50051'
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=1)) # what should the default be?
    cakework_pb2_grpc.add_CakeworkServicer_to_server(Cakework(), server)
    server.add_insecure_port('[::]:' + port)
    server.start()
    logging.info("Server started, listening on " + port)
    server.wait_for_termination()

if __name__ == '__main__':
    logging.basicConfig()
    serve()

class ActivityServer:
    def __init__(self, user_activity, local=False):
        self.user_activity = user_activity
        self.server = grpc.server(futures.ThreadPoolExecutor(max_workers=1)) # what should the default be?
        self.local = local

    def start(self):        
        port = '50051'
        cakework_pb2_grpc.add_CakeworkServicer_to_server(Cakework(self.user_activity, self.local), self.server)
        self.server.add_insecure_port('[::]:' + port)
        self.server.start()
        logging.info("Server started, listening on " + port)
        self.server.wait_for_termination()
